<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
 
Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.
 
The Original Code is comprised of the pt_social_media directory
 
The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2015.
All Rights Reserved.
 
By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable
end user license agreement.
--->

<!---
/* *************************************************************** */
Author: 	
	PaperThin Inc.
	G. Cronkright
Name:
	video_size_calc_render.cfm
Summary:
	CFT to render a video size option fields for the vidoes.
ADF App:
	pt_social_media
Version:
	3.0
History:
	2011-06-11 - GAC - Created
	2011-11-02 - GAC - Added Min and Max width value options
	2015-06-23 - DRM - Converted to CFC for CommonSpot 10/ADF 2
	2015-09-16 - GAC - Removed a misplaced VAR from the renderJS() block
	2016-02-26 - DRM - Resource detection support
--->
<cfcomponent extends="ADF.extensions.customfields.adf-form-field-renderer-base" output="no">

<cffunction name="renderControl" access="public" returnType="void">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	<cfargument name="isRequired" type="boolean" required="yes">

	<cfscript>
		var fldID = "";
		
		if (structKeyExists(arguments.parameters, "fldID") )
			fldID = trim(arguments.parameters.fldID);
		else
			fldID = arguments.fieldName;
		if (fldID == "")
			fldID = trim(replaceNoCase(arguments.fieldName, 'fic_', ''));

		renderJS(fldID=fldID, params=arguments.parameters, argumentCollection=arguments);
	</cfscript>

	<cfoutput>
		<style>
			###fldID#_FieldErrors {
				display: none;
			}
			###fldID#_FieldErrors ul {
				margin: 0 0 0 0;
				padding: 2px 0 0 0;
			}
			###fldID#_FieldErrors ul li {
				font-size: 10px;
				color: red;
				list-style-image: none;
				list-style-type: none;
				margin: 0 0 0 0;
				padding: 0 0 0 0;
			}

			###fldID#_calcBox {
				font-size: 11px;
			}
		</style>

		<div id='#fldID#_calcBox'>
			Aspect&nbsp;ratio:
			  <select id="#fldID#_aspectRatio" name="#arguments.fieldName#_aspectRatio">
					<option value="widescreen">16x9</option>
					<option value="standard">4x3</option>
			  </select> |
			  Width:
			  <input id="#fldID#_playerWidth" size="3" value="" type="text"> |
			  Height:
			  <span id="#fldID#_playerHeight"></span>

			<div id="#fldID#_FieldErrors"></div>
		</div>
		<!--- // hidden field to store the value --->
		<input type='hidden' name='#arguments.fieldName#' id='#fldID#' value='#arguments.value#'>
	</cfoutput>
</cffunction>


<cffunction name="renderJS" returntype="void">
	<cfargument name="fldID" type="string" required="yes">
	<cfargument name="params" type="struct" required="yes">

	<cfscript>
		arguments.value = trim(arguments.value);

		if (!structKeyExists(arguments.parameters, "maxWidth"))
			arguments.parameters.maxWidth = "900";
		if (!structKeyExists(arguments.parameters, "minWidth"))
			arguments.parameters.minWidth = "150";
	</cfscript>

	<cfoutput>
		<script>
			//Validation function
			function validate_#arguments.fieldName#() {
				return (jQuery("input[name=#arguments.fieldName#]").val() != '');
			}

			jQuery( function() {
				jQuery("###arguments.fldID#_FieldErrors").hide();

				// If needed, convert arguments.value back to values that can populate the fields
				<cfif len(arguments.value)>
					// - get the current width,height and aspect ratio
					// - set the aspect ratio in the drop down
					// - set the width
					// - set the height
					var currentValueWidth = parseVideoWidth_#arguments.fldID#('#arguments.value#');
					var currentValueHeight = parseVideoHeight_#arguments.fldID#('#arguments.value#');
					var currentValueAspectRatio = parseAspectRatioStyle_#arguments.fldID#(currentValueWidth,currentValueHeight);

					// Set the aspect ratio in the drop down
					jQuery("###arguments.fldID#_aspectRatio").val(currentValueAspectRatio);
					jQuery("###arguments.fldID#_playerWidth").val(currentValueWidth);
					jQuery("###arguments.fldID#_playerHeight").text(currentValueHeight);
					//setPlayerHeight_#arguments.fldID#(currentValueAspectRatio,currentValueWidth);
				<cfelse>
					var defaultValueWidth = 640;
					jQuery("###arguments.fldID#_playerWidth").val(defaultValueWidth);

					// Get the currently selected value
					var arFldValue = jQuery("###arguments.fldID#_aspectRatio option:selected").val();
					setPlayerHeight_#arguments.fldID#(arFldValue,defaultValueWidth);
				</cfif>

				// On KeyUp set the new height and verify max width
				jQuery("###arguments.fldID#_playerWidth").keyup(function (event) {
					var newWidthValue = jQuery(this).val();
					var currARvalue = jQuery("###arguments.fldID#_aspectRatio option:selected").val();
					setPlayerHeight_#arguments.fldID#(currARvalue,newWidthValue);
					// Verify Field Values
					checkForValidFieldEntries_#arguments.fldID#()
				});

				jQuery("###arguments.fldID#_aspectRatio").change(function() {
					var selectedARvalue = jQuery(this).val();
					var currWidthValue = jQuery("###arguments.fldID#_playerWidth").val();
					setPlayerHeight_#arguments.fldID#(selectedARvalue,currWidthValue);
					// Verify Field Values
					checkForValidFieldEntries_#arguments.fldID#()
				});

				// Field validation function
				function checkForValidFieldEntries_#arguments.fldID#() {
					var msg0 = "";
					var msg1 = "";
					var verifyWidthValue = jQuery("###arguments.fldID#_playerWidth").val();
					var minWidth = "#arguments.parameters.minWidth#";
					var maxWidth = "#arguments.parameters.maxWidth#";
					var errMsg;


					//var varifyARvalue = jQuery("###arguments.fldID#_aspectRatio option:selected").val();

					// Check for a min width
					if ( !verifyWidthValue.length || verifyWidthValue < minWidth ) {
						msg0 = "Player width must be at least " + minWidth + "px";
						msg0 = '<li>' + msg0 + '</li>';
						//alert(msg0);
					}
					// Check for a max width
					if ( verifyWidthValue > maxWidth ) {
						msg1 = "Player width must not be greater than " + maxWidth + "px";
						msg1 = '<li>' + msg1 + '</li>';
						jQuery("###arguments.fldID#_playerHeight").text('0');
					}
					// Build error Messages
					errMsg = msg0 + msg1;

					// Display error messages and disable submit button
					if ( errMsg.length ) {
						// Remove the invalid value from the hidden field
						jQuery("###arguments.fldID#").val('');
						// Generate Error message on near the field
						errMsg = '<ul>' + errMsg + '</ul>';
						jQuery("###arguments.fldID#_FieldErrors").show('slow').html(errMsg);
						showHideSubmitButtons_#arguments.fldID#('hide');
						lbResizeWindow();
					} else {
						jQuery("###arguments.fldID#_FieldErrors").html('').hide();
						showHideSubmitButtons_#arguments.fldID#('show');
					}
				}

				function setPlayerHeight_#arguments.fldID#(aspectRatio,vWidth) {
					var vHeight, vSizeStr;
					if ( aspectRatio == 'widescreen' ) {
						vHeight = getHeight_#arguments.fldID#(vWidth,16,9);
					} else {
						vHeight = getHeight_#arguments.fldID#(vWidth,4,3);
					}
					jQuery("###arguments.fldID#_playerHeight").text(vHeight);
					vSizeStr = buildVideoSizeStr_#arguments.fldID#(vWidth,vHeight);
					jQuery("###arguments.fldID#").val(vSizeStr);
				}

				function getHeight_#arguments.fldID#(newWidth,orginalWidth,originalHeight) {
					if (orginalWidth == 0)
						return newWidth;
					var aspectRatio = orginalWidth / originalHeight;
					return Math.round(newWidth / aspectRatio);
				}
				/* function getWidth(newHeight,orginalWidth,originalHeight) {
					if(originalHeight == 0)return newHeight;
					var aspectRatio = orginalWidth / originalHeight;
					return Math.round(newHeight * aspectRatio);
				} */
				function buildVideoSizeStr_#arguments.fldID#(vWidth,vHeight) {
					if ( vWidth.length == 0 ){
						vWidth = 0;
					}
					var vSizeStr = vWidth + 'x' + vHeight;
					return vSizeStr;
				}
				function parseVideoHeight_#arguments.fldID#(vSizeStr) {
					var vHeight = jQuery.ListLast(vSizeStr,"x");
					return vHeight;
				}
				function parseVideoWidth_#arguments.fldID#(vSizeStr) {
					var vWidth = jQuery.ListFirst(vSizeStr,"x");
					return vWidth;
				}
				function parseAspectRatioStyle_#arguments.fldID#(vWidth,vHeight) {
					//var vWidth = parseVideoWidth_#arguments.fldID#(vSizeStr);
					//var vHeight = parseVideoWidth_#arguments.fldID#(vSizeStr);
					var aspectRatioStr = 'standard';
					var aspectRatio = (vWidth / vHeight);
					var arWide = aspectRatio * 9;
					var arStandard = aspectRatio * 3;
					if ( arWide == 16 ) {
						aspectRatioStr = 'widescreen';
					} else if ( arStandard == 4 ) {
						aspectRatioStr = 'standard';
					}
					return aspectRatioStr;
				}

				// Deal with the Submit buttons
				function showHideSubmitButtons_#arguments.fldID#(status) {
					if ( status == 'hide' ) {
						// Hide CS5 style submit button
						jQuery('input[name="submitbutton"]')
							.hide()
							.attr('disabled','disabled')
							.addClass('ui-state-disabled');

						// Hide the cs footer buttons
						jQuery("##clsProxyButtonHolder").hide();
					} else if ( status == 'show') {
						// Show CS5 style submit button
						jQuery('input[name="submitbutton"]')
							.show()
							.removeAttr('disabled')
							.removeClass('ui-state-disabled');

						// Show the cs footer buttons
						jQuery("##clsProxyButtonHolder").show();
					}
				}
			});
		</script>
		</cfoutput>
</cffunction>


<cfscript>
	private any function getValidationJS(fieldName)
	{
		return "validate_#arguments.fieldName#";
	}

	public string function getResourceDependencies()
	{
		return listAppend(super.getResourceDependencies(), "jQuery,CFJS");
	}
	public string function loadResourceDependencies()
	{
		application.ptSocialMedia.scripts.loadjQuery();
		application.ptSocialMedia.scripts.loadCFJS();
	}
</cfscript>

</cfcomponent>