<!--- 
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is comprised of the pt_social_media App directory

The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2015.
All Rights Reserved.

By downloading, modifying, distributing, using and/or accessing any files 
in this directory, you agree to the terms and conditions of the applicable 
end user license agreement.
--->
<!---
/* *************************************************************** */
Author: 	
	PaperThin Inc.
	G. Cronkright
Name:
	social_media_combined_stream_rh.cfm
Summary:
	Render Handler to render out the selected Social Media Feeds
ADF App:
	pt_social_media
Version:
	3.0
History:
	2011-03-08 - GAC - Created
	2012-01-12 - GAC - Added render handler Caching code 
	2012-01-13 - GAC - File was renamed from social_media_posts_rh.cfm
	2012-03-15 - GAC - Updated the debug dump code for the element to only dump the values struct
	2012-04-24 - GAC - Updated the comments around the element CacheValidUntil code
	2012-05-04 - GAC - Added logic around the cacheValidUntil code to use the FeedCache instead if it is enabled 
	2012-05-05 - GAC - Added logic to check for the DebugTools header
	2013-06-20 - GAC - Added an useCacheOverride argument to allow disabling of the Feed Cache for debug output
					 - Update the debug tools logic
	2016-02-26 - DRM - Resource detection exit
--->

<!--- if this module loads resources, do it here.. --->
<cfscript>
	// Get the values from the Configuration Element
	uiTheme = application.ptSocialMedia.getUItheme();

	// TODO - Why are these commented out
	// Load the Facebook Graph API JS Headers Headers
	//application.ptSocialMedia.socialMediaService.loadFacebookJS();
	// Load the Twitter @Anywhere and Widgets JS Headers Headers
	//application.ptSocialMedia.socialMediaService.loadTwitterAnywhereJS();
	//application.ptSocialMedia.socialMediaService.loadTwitterWidgetsJS();

	// Load the JQuery Plugin Headers
	application.ptSocialMedia.scripts.loadjQuery();
	// load header for jQuery UI
	application.ptSocialMedia.scripts.loadJQueryUI(themeName=uiTheme);

	// Load the JQuery TimeAgo Plugin Headers
	application.ptSocialMedia.scripts.loadjQueryTimeAgo();

	// Load the JQuery CFJS Plugin Headers
	application.ptSocialMedia.scripts.loadCFJS();
	// Load the Social Media App JS Headers
	application.ptSocialMedia.socialMediaService.loadSocialMediaJS();
</cfscript>

<!--- ... then exit if all we're doing is detecting required resources --->
<cfif Request.RenderState.RenderMode EQ "getResources">
  <cfexit>
</cfif>


<cfscript>
// Get the state of the App Level Feed Cache
useFeedCache = application.ptSocialMedia.getFeedCacheState();

// Check for CS Author Mode
csMode = "";
if ( StructKeyExists(request,"renderstate") AND StructKeyExists(request.renderstate,"rendermode") ) 
	csMode = request.renderstate.rendermode;

// Check status of socialMediaDebugToolsMode variable
if ( !StructKeyExists(request,"ptSocialMedia") ) 
	request.ptSocialMedia = StructNew();
if ( !StructKeyExists(request.ptSocialMedia,"socialMediaDebugToolsMode") )
	request.ptSocialMedia.socialMediaDebugToolsMode = false;

/* 
// --- cacheValidUntil Sample code block--
// Cache for a set amount of time then refresh the cache
// - Set the number of minutes to cache
minsToCache = 5;
// - Set the rebuild Date/Time using the minutes to cache from above
rebuildDate = dateAdd("n", minsToCache, now());
// - Tell the element to cache until the rebuild date
request.element.cacheValidUntil = Mid(CreateODBCDateTime(rebuildDate),6,19);
// - Make sure that the element is static
request.element.isStatic = 1;
// --- if using cacheValidUntil comment out the 'isStatic = 0' line below
*/

request.element.isStatic = 0; 

// Set the Default for the Show Error flag
showError = true;
showModerateTools = false;

showSocialMediaToolsBtn = false;
socialMediaToolsBtnShowText = "Show Moderation Bars";
socialMediaToolsBtnHideText = "Hide Moderation Bars";

showElementDump = false;
showDataDump = false;
showFeedDump = false;
showSourceDataDump = false;
useCacheOverride = false;
noRenderHTML = false;
showTestPost = false;

// If debug tools are available allow url variables to control debug output 
if ( request.ptSocialMedia.socialMediaDebugToolsMode ) {
	request.element.isStatic = 0; // for debug mode make sure element is not Cached by CS
	
	if ( StructKeyExists(request.params,"showElement") AND IsBoolean(request.params.showElement) )
		showElementDump = request.params.showElement;
	if ( StructKeyExists(request.params,"showData") AND IsBoolean(request.params.showData) )
		showDataDump = request.params.showData;
	if ( StructKeyExists(request.params,"showFeed") AND IsBoolean(request.params.showFeed) )
		showFeedDump = request.params.showFeed;
	if ( StructKeyExists(request.params,"showSourceData") AND IsBoolean(request.params.showSourceData) )
		showSourceDataDump = request.params.showSourceData;
	if ( StructKeyExists(request.params,"disableFeedCache") AND IsBoolean(request.params.disableFeedCache) )
		useCacheOverride = request.params.disableFeedCache;
	if ( StructKeyExists(request.params,"noHTML") AND IsBoolean(request.params.noHTML) )
		noRenderHTML = request.params.noHTML;
	if ( StructKeyExists(request.params,"showTestPost") AND IsBoolean(request.params.showTestPost) )
		showTestPost = request.params.showTestPost;
}

// Set variabless for items that should only be show in author mode and with the correct user rights
if ( ListFindNoCase("author,edit",csMode) ) {
	showSocialMediaToolsBtn = true;
	showModerateTools = true;
}	
</cfscript>
<!--- <cfdump var="#attributes.elementinfo.elementdata.propertyValues#" expand=false> --->
<!--- <cfdump var="#cgi#" expand=false> --->

<!--- // Check to see if the Element has Data --->
<cfif arrayLen(attributes.elementinfo.elementdata.propertyValues) gt 0>
<cfscript>
	// Made it past the initial data check ... turn off the error 
	showError = false;
	outputHTML = true;
		
	//Set Ajax Proxy Path
	AjaxPath = application.ADF.ajaxProxy;
	
	//Set the Controller Bean and the RomoveMethod
	ControllerBean = "feedController";
	RemoveMethod = "removePost";
	
//application.ptSocialMedia.scripts.setDebugMode(debugMode=true);
	
	// Get the data items in the RH
	selectedFeeds = attributes.elementInfo.elementData.propertyValues;

	// Since we are only worried about what is in the first array item grab that one
	selectedFeedStruct = StructNew();
	if ( ArrayLen(selectedFeeds) )
		selectedFeedStruct = selectedFeeds[1];

// TODO: Add admin/contributor rights check around this DUMP	
if ( showElementDump AND StructKeyExists(selectedFeedStruct,"values") )					
	application.ptSocialMedia.utils.doDump(selectedFeedStruct.values,"selectedFeedStruct",0);		

	items = ArrayNew(1);
	maxRenderLimit = 10;
	facebookLikeButtonStyle = "Button Count"; //Standard
	likeStyle = "button_count";
	likeWidth = 200;
	twitterTweetButtonStyle = "No Count";
	tweetStyle = "none";
	showSourceLinks = "No Display";
	sourceLinksPosition = "";
	youTubeThumbImageHTML = "";
	openYouTubePlayersInLB = "No";
	lbYouTubePlayerWidth = "480"; //Default: 480x270 aspect ratio 16:9
	lbYouTubePlayerHeight = "270"; 
	
	// Make sure Feed Selector Element Returns selected feed records
	if ( StructKeyExists(selectedFeedStruct,"values") ) {
		
		// Get the RenderLimit from the selected feed meta data
		if ( StructKeyExists(selectedFeedStruct.values,"renderLimit") )
			maxRenderLimit = selectedFeedStruct.values.renderLimit;
		// Get the fbLikeButtonStyle from the selected feed meta data
		if ( StructKeyExists(selectedFeedStruct.values,"fbLikeButtonStyle") )
			facebookLikeButtonStyle = selectedFeedStruct.values.fbLikeButtonStyle;
		// Get the tweetButtonStyle from the selected feed meta data
		if ( StructKeyExists(selectedFeedStruct.values,"tweetButtonStyle") )
			twitterTweetButtonStyle = selectedFeedStruct.values.tweetButtonStyle;
		// Get the tweetButtonStyle from the selected feed meta data
		if ( StructKeyExists(selectedFeedStruct.values,"displaySourcesLinks") ) 
			showSourceLinks = selectedFeedStruct.values.displaySourcesLinks;
		// Get the youtubePlayersInLB from the selected feed meta data
		if ( StructKeyExists(selectedFeedStruct.values,"youtubePlayersInLB") ) 
			openYouTubePlayersInLB = selectedFeedStruct.values.youtubePlayersInLB;
		// Get the youtubePlayerSizeInLB from the selected feed meta data
		// - Convert the value to a width and a height 
		if ( StructKeyExists(selectedFeedStruct.values,"youtubePlayerSizeInLB") AND LEN(TRIM(selectedFeedStruct.values.youtubePlayerSizeInLB)) ) {
			youtubePlayerSizeInLB = selectedFeedStruct.values.youtubePlayerSizeInLB ;
			if ( IsNumeric(ListFirst(youtubePlayerSizeInLB,"x")) )
				lbYouTubePlayerWidth = ListFirst(youtubePlayerSizeInLB,"x"); 
			if ( IsNumeric(ListLast(youtubePlayerSizeInLB,"x")) )
				lbYouTubePlayerHeight = ListLast(youtubePlayerSizeInLB,"x");
		}

		// Facebook Button CE Options: No Button, Standard, Button Count, Box Count
		// FB Parameter Values: standard, button_count, box_count 
		if ( facebookLikeButtonStyle EQ "Button Count" )
			likeStyle = "button_count";
		else if ( facebookLikeButtonStyle EQ "Box Count" )
			likeStyle = "box_count";
		else if ( facebookLikeButtonStyle EQ "Standard" )	
			likeStyle = "standard";
		
		// Twitter Button CE Options: No Button, No Count, Vertical Count, Horizontal Count
		// Twitter Parameter Values: none, horizontal, vertical
		if ( twitterTweetButtonStyle EQ "Vertical Count" )
			tweetStyle = "vertical";
		else if ( twitterTweetButtonStyle EQ "Horizontal Count" )
			tweetStyle = "horizontal";
		else if ( twitterTweetButtonStyle EQ "No Count" )	
			tweetStyle = "none";
			
		// Set the source link display position			
		if ( showSourceLinks EQ "Links on Top" )
			sourceLinksPosition = "top";
		else if ( showSourceLinks EQ "Links on Bottom" )
			sourceLinksPosition = "bottom";

		// Get Feed Data from the Combined from the selected Feeds	
		items = application.ptSocialMedia.feedController.buildComibinedFeedItems(
					selectedFeeds=selectedFeedStruct
					,sortOrder="desc"
					,sortField="PublishedDate"
					,addTestData=showTestPost
					,showFeedDump=showFeedDump
					,useCacheOverride=useCacheOverride
				);	
			
// TODO: Add admin/contributor rights check around this DUMP	
if ( showDataDump )					
	application.ptSocialMedia.utils.doDump(items,"items",0);
	
		// Set the Max Number of Result to display	
		if ( ArrayLen(items) LT maxRenderLimit )
			maxRenderLimit = ArrayLen(items);
	
		// Get Feed Souce Link data for the selected Feeds	
		if ( LEN(TRIM(showSourceLinks)) ) {
			sourceItems = application.ptSocialMedia.feedController.buildFeedSourceData(
								feedItems=items,
								renderedItemCount=maxRenderLimit
							);

// TODO: Add admin/contributor rights check around this DUMP					
if ( showSourceDataDump )
	application.ptSocialMedia.utils.doDump(sourceItems,"sourceItems",0);

		}
	}	
	
	if ( ArrayLen(items) EQ 0 )
		showError = true;	
	
	if ( noRenderHTML )
		outputHTML = false;
	
	// Do not Show Moderation Tools if there are no items returned (or if there was an error)
	//if ( showError ) {
		//showSocialMediaToolsBtn = false;
		//showModerateTools = false;
	//}
</cfscript>

<cfif outputHTML AND !showError>
	<cfoutput>
	<!--- // Add the CSS file for the App via the CommonSpot > Manage > Style Sheets --->
	<!--- <link href="/ADF/apps/pt_social_media/style/socialmedia.css" type="text/css" rel="stylesheet" />  --->
	
	<script type="text/javascript">
		jQuery( function() {
			// Allow future times for bad Feed times (not needed)
			//jQuery.timeago.settings.allowFuture = true;
			
			// Use to add TIMEAGO to server rendered datatime stamps
			jQuery("abbr.timeago").timeago();
			
			// Rewrite the TITLE attribute of the ABBR tag with human readable date/time  
			jQuery("abbr.timeago").each(function(i){
				// Grab the ISO datetime from the title attribute
				var isoDT = jQuery(this).attr("rel");
				// Convert ISO8601 DateTime to a JS DateTime Object
				var parseDT = jQuery.timeago.parse(isoDT);
				// Convert to Users local Date/Time (function in the socialmedia.js file)
				var localDT = buildUsersLocalDateTime(parseDT);
				// Format Date and Time and Create Formatted DateTime Stamp
				var fmtD = jQuery.DateFormat(localDT,"dddd, mmmm d, yyyy"); // mm - Month
				var fmtT = jQuery.TimeFormat(localDT,"h:MM tt");      // MM - minutes with leading zero
				var formatDT = fmtD + " at " + fmtT;
				// Rewrite back to the Title attribute
				jQuery(this).attr("title",formatDT);
			});
			
		<cfif showSocialMediaToolsBtn>
			// hide/show all the remove post tool bars	
			jQuery(".smRemovePost").hide();	
			jQuery(".smToolLink").click(function() {
				if ( jQuery(".smRemovePost").is(':visible') ) { //:hidden
	                 jQuery(".smToolLink").text("#socialMediaToolsBtnShowText#");
	                 jQuery(".smRemovePost").hide();
	            } else {
	                 jQuery(".smToolLink").text("#socialMediaToolsBtnHideText#");
	                 jQuery(".smRemovePost").show();
	            }	
			});
		</cfif>	
			
		<cfif showModerateTools>		
			// Hide all "working..." images
			jQuery(".smRemovePostWorking").hide();
				
			jQuery(".smRemovePost").click(function() {
				clickid = jQuery(this).attr("id");
		    	clickedArray = clickid.split("|");
		    	postaction = clickedArray[0];
		    	itemid = clickedArray[1];
		    	servicetype = clickedArray[2];
		    	feedid = clickedArray[3];
		    	postid = clickedArray[4];
				// Make AjaxProxy call to controller function
				// - Pass itemid, serivetype, feedid and postid 
				removePost(itemid,servicetype,feedid,postid)
			});
			
			function removePost(i,s,f,p) {
		    	if ( confirm("Are you sure you want to remove this post?") ) {
	
					// Add Start/Show Status Image
					jQuery("##item-" + i + " .smRemovePostText").hide();
					jQuery("##item-" + i + " .smRemovePostWorking").show();
					
			    	jQuery.get("#AjaxPath#",
						{
							method: '#RemoveMethod#'
							,bean: '#ControllerBean#'
							,servicetype: s
							,feedid: f 
							,postid: p 
							,returnformat: "json"
						},
							function(data){
								// On Success... 
								// Stop/Hide Status Image						
								// jQuery("##item-" + i + " .smRemovePostWorking").hide();
								
								// Remove Post from the Page
								jQuery("##item-" + i).slideUp("slow");
						},
						"json"
					); 
					
				} 
		    }
		    
		    // Hover states on the remove Post tool bar
			jQuery("div.smRemovePost").hover(
				function() { 
					jQuery(this).css("cursor", "hand");
					jQuery(this).addClass('smRemovePostOver');
				},
				function() { 
					jQuery(this).css("cursor", "pointer");
					jQuery(this).removeClass('smRemovePostOver');
				}
			);
		</cfif>
		
		});	
	
	</script>	
		
	<div id="smPage">
	
		<cfif showSocialMediaToolsBtn>
		<div id="smToolLinkMenuTop" class="smToolLinkMenu">
			<a href="javascript:;" class="smToolLink ui_button ui-state-default ui-corner-all">#socialMediaToolsBtnShowText#</a>
		</div>
		</cfif>
		
		<!--- // Build the Display for the Source Links --->
		<cfif sourceLinksPosition EQ "top" AND ArrayLen(sourceItems)>
		<div id="smSourceLinksTop" class="smSourceLinks">
			<div class="smSourceLinksHeader">
				Social Media Resources:
				<!--- <cfmodule template="/commonspot/utilities/ct-render-named-element.cfm"
					elementName="smSourceLinksTopHeaderText#request.element.id#"
					elementType="tb-simple-nohdr"> --->
			</div>
			<cfloop from="1" to="#ArrayLen(sourceItems)#" index="srcItm">
			<div class="smSourceLink">
				<cfif LEN(TRIM(sourceItems[srcItm].FeedLink))><a href="#sourceItems[srcItm].FeedLink#" target="_blank" title="#UCASE(sourceItems[srcItm].SERVICETYPE)#"></cfif><img src="#sourceItems[srcItm].SERVICELOGO#" class="smServiceImageSmall" alt="#UCASE(sourceItems[srcItm].SERVICETYPE)#" /><cfif LEN(TRIM(sourceItems[srcItm].FeedLink))></a></cfif>
				<cfif LEN(TRIM(sourceItems[srcItm].FeedName))>
					<cfif LEN(TRIM(sourceItems[srcItm].FeedLink))><a href="#sourceItems[srcItm].FeedLink#" target="_blank" title="#UCASE(sourceItems[srcItm].SERVICETYPE)#"></cfif>#sourceItems[srcItm].FeedName#<cfif LEN(TRIM(sourceItems[srcItm].FeedLink))></a></cfif>
				</cfif>
			</div>
			</cfloop>
		</div>
		</cfif>
		
		<!--- <h3>Social Media Feeds Mashup RH - (#request.page.title#)</h3> --->
		
		<div id="smPosts">
		<!--- // Loop over Combined Feed Results --->
		<cfloop from="1" to="#maxRenderLimit#" index="itm">
			
			<div class="smPost" id="item-#itm#">
			
			<cfif showModerateTools AND LEN(TRIM(items[itm].content.postid))>
				<cfset removeID = itm & "|" & items[itm].ServiceType & "|" & items[itm].feedid & "|" & items[itm].content.postid>
				<div class="smToolsInit smRemovePost #items[itm].ServiceType#" id="remove|#removeID#">
					<div class="smRemovePostText">Remove This Post <span>X</span></div>
					<div class="smRemovePostWorking">
						<img alt="Working to remove post..." width="16" height="16" src="/ADF/apps/pt_social_media/images/ajax-loader-arrows.gif"/> Working to remove post...
					</div>
				</div>
			</cfif>	
	
			<!--- <div>Post ID: #items[itm].content.postid#</div> --->
	
			<cfif LEN(TRIM(items[itm].FeedImage))>
				<cfif LEN(TRIM(items[itm].FeedLink))><a href="#items[itm].FeedLink#" target="_blank"></cfif>
				<img src="#items[itm].FeedImage#" class="smFeedImage" alt="#items[itm].FEEDNAME#" />
				<cfif LEN(TRIM(items[itm].FeedLink))></a></cfif>
			</cfif>
				
				<div class="<cfif LEN(TRIM(items[itm].FeedImage))>smFeedInfo<cfelse>smFeedInfoWide</cfif> smName">
		
					<b>
						<cfif LEN(TRIM(items[itm].FeedLink))><a href="#items[itm].FeedLink#" target="_blank"><cfelse><a href="javascript:;"></cfif>
						#items[itm].FEEDNAME#
						</a>
					</b>
					<br class="smClear" />
					
					<div class="smContentPanel" id="content-#itm#">
						
						<cfset smMessage = application.ptSocialMedia.data.trimStringByWordCount(items[itm].CONTENT.Message,100,1)>		
						<cfset smMessageHTML = application.ptSocialMedia.data.activateURL(strText=smMessage,target="_blank",paragraph="false")>	
							
						<cfset smDescription = application.ptSocialMedia.data.trimStringByWordCount(items[itm].CONTENT.Description,100,1) >
						<cfset smDescriptionHTML = application.ptSocialMedia.data.activateURL(strText=smDescription,target="_blank",paragraph="false")>	
						
						
						
						<cfif LEN(TRIM(items[itm].SOURCE.Photo)) AND items[itm].SOURCE.Photo NEQ items[itm].FeedImage>	
							<cfif LEN(TRIM(items[itm].SOURCE.Link))><a href="#items[itm].SOURCE.Link#" target="_blank"></cfif>
							<img src="#items[itm].SOURCE.Photo#" class="smSourceImage" alt="#items[itm].SOURCE.NAME#" />
							<cfif LEN(TRIM(items[itm].SOURCE.Link))></a></cfif>
						</cfif>
						
					
						<!--- Should add a config option to add extra Lightbox link code or not --->
						<!---  --->
						
						<!--- // Build YouTube Thumbnail Image HTML if needed --->
						<cfset youTubeThumbImageHTML = "">
						<cfif LEN(TRIM(items[itm].Content.Thumbnail)) AND items[itm].SERVICETYPE EQ "youtube">
							<cfsavecontent variable="youTubeThumbImageHTML">
							<img src='#items[itm].Content.Thumbnail#' class='smContentImage' alt='#smMessage#' />
							</cfsavecontent>
						</cfif>
						
						<div class="<cfif LEN(TRIM(youTubeThumbImageHTML))>smSourceInfoWide <cfelse>smSourceInfo </cfif>smName">
							
							<cfif LEN(TRIM(items[itm].SOURCE.NAME)) AND (LCASE(items[itm].SOURCE.NAME) NEQ LCASE(items[itm].FEEDNAME))>
							<b>
								
								<cfif LEN(TRIM(items[itm].SOURCE.Link))><a href="#items[itm].SOURCE.Link#" target="_blank" title="#items[itm].SOURCE.NAME#"><cfelse><a href="javascript:;"></cfif>
									#items[itm].SOURCE.NAME#
								<cfif LEN(TRIM(items[itm].SOURCE.Link))></a><cfelse></a></cfif>
								
							</b>
							<br class="smClear" />
							</cfif>
							
							<!--- // Render the Title Under the Source Name if no Description --->
							<cfif LEN(TRIM(smDescription)) EQ 0 AND LEN(TRIM(items[itm].Content.Title))>
							<b>
								
								<cfif LEN(TRIM(items[itm].Content.Link))><a href="#items[itm].Content.Link#" target="_blank" title="#smMessage#"><cfelse><a href="javascript:;"></cfif>
								#items[itm].Content.Title#
								<cfif LEN(TRIM(items[itm].Content.Link))></a></cfif>
								
							</b>
							<br class="smClear" />
							</cfif>
							
							<span>#smMessageHTML#</span>
							
							<cfif application.ptSocialMedia.data.countWordsInString(smMessage) GT 100 AND LEN(TRIM(items[itm].Content.Link))>
							<div style="text-align: right;">
								<a href="#items[itm].Content.Link#" target="_blank" title="Read More...">
								Read More
								</a>
							</div>
							</cfif>
	
							<div class="smContentImagePanel">
								<cfif LEN(TRIM(items[itm].Content.Thumbnail))>
									
									<cfif LEN(TRIM(smMessage)) EQ 0 AND LEN(TRIM(items[itm].Content.Title))>
										<cfset smMessage = items[itm].Content.Title>
									</cfif>
									
									<!--- // Add Lightbox for youtube media player by adding in Lightbox proxy code 
										  // around the thumbnail IMAGE  and the media title and under the source name
										  // also check to see if this is a YouTube post or not --->
									<cfif openYouTubePlayersInLB EQ "yes" AND items[itm].SERVICETYPE EQ "youtube">
										
										<cfif LEN(TRIM(youTubeThumbImageHTML))>
											#application.ptSocialMedia.ui.buildLightboxProxyLink(
																linkTitle=smMessage
																,bean="youTubeFeedsService"
																,method="renderYouTubeVideoPlayer"
																,urlParams="videoID=#items[itm].Content.postID#&videoHeight=#lbYouTubePlayerHeight#&videoWidth=#lbYouTubePlayerWidth#" 
																,lbTitle=items[itm].Content.Title
																,appName="ptSocialMedia"
																,linkClass=""
																,linkText=youTubeThumbImageHTML
														)# 
										</cfif>	
										
									<cfelse>
										<cfif LEN(TRIM(items[itm].Content.Link))><a href="#items[itm].Content.Link#" target="_blank" title="#smMessage#"></cfif>
										<img src="#items[itm].Content.Thumbnail#" class="smContentImage" alt="#smMessage#" />
										<cfif LEN(TRIM(items[itm].Content.Link))></a></cfif>
									</cfif>
								</cfif>
								
								<cfif LEN(TRIM(items[itm].Content.Title)) OR LEN(TRIM(smDescription))>
								<div class="<cfif LEN(TRIM(youTubeThumbImageHTML))>smContentInfoNarrow <cfelse>smContentInfo </cfif>smName">
									
									<cfif LEN(TRIM(smDescription))>
										<!--- // Render the Title above the Description if there is one --->
										<cfif LEN(TRIM(items[itm].Content.Title))>
										<b>
											<cfif openYouTubePlayersInLB EQ "yes" AND items[itm].SERVICETYPE EQ "youtube">
												#application.ptSocialMedia.ui.buildLightboxProxyLink(
															linkTitle=items[itm].Content.Title
															,bean="youTubeFeedsService"
															,method="renderYouTubeVideoPlayer"
															,urlParams="videoID=#items[itm].Content.postID#&videoHeight=#lbYouTubePlayerHeight#&videoWidth=#lbYouTubePlayerWidth#" 
															,lbTitle=items[itm].Content.Title
															,appName="ptSocialMedia"
															,linkClass="smLightBoxLink"
														)#
											<cfelse>
												<cfif LEN(TRIM(items[itm].Content.Link))><a href="#items[itm].Content.Link#" target="_blank" title="#smMessage#"><cfelse><a href="javascript:;"></cfif>
												#items[itm].Content.Title#
												<cfif LEN(TRIM(items[itm].Content.Link))></a><cfelse></a></cfif>
											</cfif> 
										</b>
										<br class="smClear" />
										</cfif>
										<span>#smDescriptionHTML#</span>
										<cfif application.ptSocialMedia.data.countWordsInString(smDescription) GT 100 AND LEN(TRIM(items[itm].Content.Link))>
										<div style="text-align: right;">
											<a href="#items[itm].Content.Link#" target="_blank" title="Read More...">
											Read More
											</a>
										</div>
										</cfif>
									</cfif>
									
								</div>
								</cfif>
								
							</div>
							
							
						</div>
						<br class="smClear" />
								
					</div>
					
					<div class="smServicePanel">
						
						<!--- // DEV: date/time  --->
						<!---
						 <div>#items[itm].PUBLISHEDDATE#</div>
						<cfset realDTgmt = application.ptSocialMedia.date.ISOToDateTime(items[itm].PUBLISHEDDATE)>
						<div>#realDTgmt#</div>
						<cfset timeAgoText = application.ptSocialMedia.date.timeAgo(dateThen=realDTgmt)> 
						<div>#timeAgoText#</div>
						 --->
						
						<cfif LEN(TRIM(items[itm].FeedLink))><a href="#items[itm].FeedLink#" target="_blank" title="#UCASE(items[itm].SERVICETYPE)#"></cfif><img src="#items[itm].SERVICELOGO#" class="smServiceImage" alt="#UCASE(items[itm].SERVICETYPE)#" /><cfif LEN(TRIM(items[itm].FeedLink))></a></cfif>
						<span class="smDTstampBox smDTnormal">
							
							<!--- // Use the Content Link around the "TIME AGO" ABBR timestamp tag --->
							<!--- // The UTC-0 time in the TITLE and TEXT of the ABBR tag is for the JQuery TimeAgo pluggin --->
							<!--- // The UTC-0 time in the REL link is for the jQuery rewrite of the timestamp into TITLE tag using the browser's local date and time with date/time formatting  --->
							<cfif LEN(TRIM(items[itm].Content.Link))><a href="#items[itm].Content.Link#" target="_blank"></cfif>
							<abbr class="timeago" title="#items[itm].PUBLISHEDDATE#" rel="#items[itm].PUBLISHEDDATE#">#items[itm].PUBLISHEDDATE#</abbr>
							<cfif LEN(TRIM(items[itm].Content.Link))></a></cfif>
							
							<!--- // Need the Browser time offset... to do this right!! --->
							<!--- // CF only gives the server time offset --->
							<!--- <abbr class="timeagoCF" title="#DateFormat(realDTgmt,'long')#" rel="#realDTgmt#">#timeAgoText#</abbr> --->
							
						
						</span>
	
					</div>

					<!--- //DEV Code: --->
					<!--- TW: #twitterTweetButtonStyle# | FB: #facebookLikeButtonStyle# --->
	
					<cfif twitterTweetButtonStyle NEQ "No Button" OR facebookLikeButtonStyle NEQ "No Button">
					<div id="smButtons">
					
						<cfif twitterTweetButtonStyle NEQ "No Button">
						<div class="smTweetButton">
							
							#application.ptSocialMedia.twitterAPI.buildTweetButtonUI(
									url=items[itm].TweetBtn.Link
									,text=items[itm].TweetBtn.message
									,count=tweetStyle
								)#
								
						</div>
						</cfif>
						
						<cfif facebookLikeButtonStyle NEQ "No Button">
						
							<!--- // To "Like" an FB users "status" you must be a friend or do some Oauth work  --->
							<cfif items[itm].FEEDTYPE NEQ "facebook" AND items[itm].FEEDTYPE NEQ "status">
							<div class="smLikeButton">

								#application.ptSocialMedia.facebookAPI.buildLikeButtonUI(
									href=items[itm].FBLikeBtn.Link
									,layout=likeStyle
									,width=likeWidth
									,embedType="html5"
								)# 
								
							</div>
							</cfif>
							
						</cfif>
	
						<div class="smClear"></div>
	
					</div>
					</cfif>
					
					<div class="smClear"></div> 
					
				</div>
				 
				<br class="smClear" />
			
			</div>
		</cfloop>
		</div>
		
		<cfif showSocialMediaToolsBtn>
		<br class="smClear" />
		
		<div id="smToolLinkMenuBottom" class="smToolLinkMenu">
			<a href="javascript:;" class="smToolLink ui_button ui-state-default ui-corner-all">#socialMediaToolsBtnShowText#</a>
		</div>
		</cfif>
		
		<!--- // Build the Display for the Source Links --->
		<cfif sourceLinksPosition EQ "bottom" AND ArrayLen(sourceItems)>
		<br class="smClear" />
		
		<div id="smSourceLinksBottom" class="smSourceLinks">
			<div class="smSourceLinksHeader">
				Social Media Resources:
				<!--- <cfmodule template="/commonspot/utilities/ct-render-named-element.cfm"
					elementName="smSourceLinksBottomHeaderText#request.element.id#"
					elementType="tb-simple-nohdr"> --->
			</div>
			<cfloop from="1" to="#ArrayLen(sourceItems)#" index="srcItm">
			<div class="smSourceLink">
				<cfif LEN(TRIM(sourceItems[srcItm].FeedLink))><a href="#sourceItems[srcItm].FeedLink#" target="_blank" title="#UCASE(sourceItems[srcItm].SERVICETYPE)#"></cfif><img src="#sourceItems[srcItm].SERVICELOGO#" class="smServiceImageSmall" alt="#UCASE(sourceItems[srcItm].SERVICETYPE)#" /><cfif LEN(TRIM(sourceItems[srcItm].FeedLink))></a></cfif>
				<cfif LEN(TRIM(sourceItems[srcItm].FeedName))>
					<cfif LEN(TRIM(sourceItems[srcItm].FeedLink))><a href="#sourceItems[srcItm].FeedLink#" target="_blank" title="#UCASE(sourceItems[srcItm].SERVICETYPE)#"></cfif>#sourceItems[srcItm].FeedName#<cfif LEN(TRIM(sourceItems[srcItm].FeedLink))></a></cfif>
				</cfif>
			</div>
			</cfloop>
		</div>
		</cfif>
		
	</div>
	</cfoutput>
	</cfif><!--- // END - outputHTML AND !Show Error --->
</cfif> <!--- // END - ArrayLen(...propertyValues)--->

<!--- // If no Records are returned and If page is in Author/Edit Mode, output the select warning --->
<cfif showError>
<cfoutput>
<br style="clear: all;" />
<div class="smErrorBanner">
	<cfif ListFindNoCase("author,edit",csMode)>
	<div class="smErrorText">(Nothing to display!)</div>
	</cfif>
</div>			
</cfoutput>
</cfif>